@@ -55,12 +55,14 @@ var (
 		// still be available for completion
 		Aliases: func() []*console.Alias {
 			binNames := php.GetBinaryNames()
-			aliases := make([]*console.Alias, 0, len(binNames))
+			aliases := make([]*console.Alias, 0, len(binNames)+1)
 
 			for _, name := range php.GetBinaryNames() {
 				aliases = append(aliases, &console.Alias{Name: name})
 			}
 
+			aliases = append(aliases, &console.Alias{Name: "pie"})
+
 			return aliases
 		}(),
 		Action: func(c *console.Context) error {
