@@ -59,8 +59,9 @@ func testStdoutCapture(c *C, dst io.Writer) func() {
 
 	return func() {
 		// Close the writer end of the pipe
-		w.Sync()
-		w.Close()
+		if err := w.Close(); err != nil {
+			c.Errorf("err: %s", err)
+		}
 
 		// Reset stdout
 		os.Stdout = old
@@ -99,11 +100,12 @@ func TestHelperProcess(t *testing.T) {
 		for _, v := range os.Environ() {
 			fmt.Println(v)
 		}
+		os.Exit(0)
 	case "exit-code":
 		code, _ := strconv.Atoi(os.Args[4])
 		os.Exit(code)
 	}
-	os.Exit(0)
+	os.Exit(1)
 }
 
 func (s *ExecutorSuite) TestNotEnoughArgs(c *C) {
@@ -112,6 +114,14 @@ func (s *ExecutorSuite) TestNotEnoughArgs(c *C) {
 	c.Assert((&Executor{BinName: "php"}).Execute(true), Equals, 1)
 }
 
+func (s *ExecutorSuite) TestCommandLineFormatting(c *C) {
+	c.Assert((&Executor{}).CommandLine(), Equals, "")
+
+	c.Assert((&Executor{Args: []string{"php"}}).CommandLine(), Equals, "php")
+
+	c.Assert((&Executor{Args: []string{"php", "-dmemory_limit=-1", "/path/to/composer.phar"}}).CommandLine(), Equals, "php -dmemory_limit=-1 /path/to/composer.phar")
+}
+
 func (s *ExecutorSuite) TestForwardExitCode(c *C) {
 	defer restoreExecCommand()
 	fakeExecCommand("exit-code", "5")
@@ -131,6 +141,63 @@ func (s *ExecutorSuite) TestForwardExitCode(c *C) {
 	c.Assert((&Executor{BinName: "php", Args: []string{"php"}}).Execute(true), Equals, 5)
 }
 
+func (s *ExecutorSuite) TestExecutorRunsPHP(c *C) {
+	defer restoreExecCommand()
+	execCommand = func(name string, arg ...string) *exec.Cmd {
+		c.Assert(name, Equals, "../bin/php")
+
+		cmd := exec.Command(os.Args[0], "-test.run=TestHelperProcess", "--", "exit-code", "0")
+		cmd.Env = []string{"GO_WANT_HELPER_PROCESS=1"}
+		// Set the working directory right now so that it can be changed by
+		// calling test case
+		cmd.Dir, _ = os.Getwd()
+		return cmd
+	}
+
+	home, err := filepath.Abs("testdata/executor")
+	c.Assert(err, IsNil)
+
+	homedir.Reset()
+	os.Setenv("HOME", home)
+	defer homedir.Reset()
+
+	oldwd, _ := os.Getwd()
+	defer os.Chdir(oldwd)
+	os.Chdir(filepath.Join(home, "project"))
+	defer cleanupExecutorTempFiles()
+
+	c.Assert((&Executor{BinName: "php", Args: []string{"php"}}).Execute(true), Equals, 0)
+
+}
+
+func (s *ExecutorSuite) TestBinaryOtherThanPhp(c *C) {
+	defer restoreExecCommand()
+	execCommand = func(name string, arg ...string) *exec.Cmd {
+		c.Assert(name, Equals, "not-php")
+
+		cmd := exec.Command(os.Args[0], "-test.run=TestHelperProcess", "--", "exit-code", "0")
+		cmd.Env = []string{"GO_WANT_HELPER_PROCESS=1"}
+		// Set the working directory right now so that it can be changed by
+		// calling test case
+		cmd.Dir, _ = os.Getwd()
+		return cmd
+	}
+
+	home, err := filepath.Abs("testdata/executor")
+	c.Assert(err, IsNil)
+
+	homedir.Reset()
+	os.Setenv("HOME", home)
+	defer homedir.Reset()
+
+	oldwd, _ := os.Getwd()
+	defer os.Chdir(oldwd)
+	os.Chdir(filepath.Join(home, "project"))
+	defer cleanupExecutorTempFiles()
+
+	c.Assert((&Executor{BinName: "php", Args: []string{"not-php"}}).Execute(true), Equals, 0)
+}
+
 func (s *ExecutorSuite) TestEnvInjection(c *C) {
 	defer restoreExecCommand()
 	fakeExecCommand("dump-env")
@@ -147,7 +214,11 @@ func (s *ExecutorSuite) TestEnvInjection(c *C) {
 	os.Chdir(filepath.Join(home, "project"))
 
 	os.Rename("git", ".git")
-	defer os.Rename(".git", "git")
+	defer func() {
+		// handling error is not really worth it here: we could not really recover it anyway and the original directory
+		// is commited
+		_ = os.Rename(".git", "git")
+	}()
 	defer cleanupExecutorTempFiles()
 
 	var output bytes.Buffer
@@ -166,8 +237,12 @@ func (s *ExecutorSuite) TestEnvInjection(c *C) {
 	projectFile := filepath.Join(".platform", "local", "project.yaml")
 	contents, err := os.ReadFile(projectFile)
 	c.Assert(err, IsNil)
-	defer os.WriteFile(projectFile, contents, 0644)
-	os.WriteFile(projectFile, bytes.Replace(contents, []byte("bew7pfa7t2ut2"), []byte("aew7pfa7t2ut2"), 1), 0644)
+	defer func() {
+		// handling error is not really worth it here: we could not really recover it and anyway the original file
+		// content is commited
+		_ = os.WriteFile(projectFile, contents, 0644)
+	}()
+	c.Assert(os.WriteFile(projectFile, bytes.Replace(contents, []byte("bew7pfa7t2ut2"), []byte("aew7pfa7t2ut2"), 1), 0644), IsNil)
 
 	output.Reset()
 	outCloser = testStdoutCapture(c, &output)
